local addonName, addon = ...
addon.L = addon.L or {} --setup localization
local L = setmetatable(addon.L, {__index = function(t,i) return i end} )


local defaults = {
	global = {
		["enabled"] = true,
		["announces"] = {
			yell = true,
			raid = false,
			raidWarning = true,
			privateRaidWarning = false,
			privateChatMessage = false,
		},
		["priorities"] = {
			["1"] = "yo no",
			["2"] = "el puma",
			["3"] = "el espiritu santo",
		},
	},
}

local optionsTable = {
    name = addonName,
    handler = addon,
    type = 'group',
    args = {
		enable = {
			name = L.Enable,
			type = 'toggle',
			order = 1,
			set = function(_, enabled)
				addon.db.global.enabled = enabled
				if enabled then
					addon:Enable()
				else
					addon:Disable()
				end
			end,
			get = function() return addon.db.global.enabled end,
		},
		reset = {
			name = L['Restore Defaults'],
			desc = L['Restore all combinations to default.'],
			type = 'execute',
			order = 2,
			func = function()
				addon.db:ResetDB()
			end,
		},
		priorities = {
			name = L['People to stay in Ultraxion'],
			desc = L['Who is gonna stay in each round'],
			type = 'group',
			order = 3,
			args = {
			  ["1"] = {
          type = 'input',
          order = 1,
          name = L['First'],
          multiline = 2,
          set = function(_, value)
            addon.db.global.priorities["1"] = value
          end,
		      get = function() return addon.db.global.priorities["1"] end,
	      },
	      ["2"] = {
          type = 'input',
          name = L['Second'],
          multiline = 2,
          set = function(_, value)
            addon.db.global.priorities["2"] = value
          end,
		      get = function() return addon.db.global.priorities["2"] end,
	      },
	      ["3"] = {
          type = 'input',
          name = L['Third (only heroic)'],
          multiline = 2,
          set = function(_, value)
            addon.db.global.priorities["3"] = value
          end,
		      get = function() return addon.db.global.priorities["3"] end,
	      },				
			},
		},
		output = {
			name = L.Output,
			desc = L['Setup where output messages are sent.'],
			type = 'group',
			order = 4,
			args = {
				yell = {
					name = L.Yell,
					type = 'toggle',
					order = 1,
					set = function(_, enabled)
						addon.db.global.announces.yell = enabled
					end,
					get = function() return addon.db.global.announces.yell end,
				},
				raid = {
					name = L.Raid,
					type = 'toggle',
					order = 2,
					set = function(_, enabled)
						addon.db.global.announces.raid = enabled
					end,
					get = function() return addon.db.global.announces.raid end,
				},
				raidWarning = {
					name = L['Raid Warning'],
					type = 'toggle',
					order = 3,
					set = function(_, enabled)
						addon.db.global.announces.raidWarning = enabled
					end,
					get = function() return addon.db.global.announces.raidWarning end,
				},
				privateRaidWarning = {
					name = L['Private Raid Warning'],
					type = 'toggle',
					order = 4,
					set = function(_, enabled)
						addon.db.global.announces.privateRaidWarning = enabled
					end,
					get = function() return addon.db.global.announces.privateRaidWarning end,
				},
				privateChatMessage = {
					name = L['Private Chat Message'],
					type = 'toggle',
					order = 5,
					set = function(_, enabled)
						addon.db.global.announces.privateChatMessage = enabled
					end,
					get = function() return addon.db.global.announces.privateChatMessage end,
				},
			},
		},
    },
}

function addon:SetupDB()
	self.db = LibStub("AceDB-3.0"):New("UltraxionPriorityDB", defaults)
end

function addon:SetupOptions()	  
	LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, optionsTable)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName)
end